@@ -1,11 +1,12 @@
 package Data::Unixish::ANSI;
 
+our $DATE = '2015-08-17'; # DATE
+our $VERSION = '0.06'; # VERSION
+
 use 5.010001;
 use strict;
 use warnings;
 
-our $VERSION = '0.05'; # VERSION
-
 1;
 # ABSTRACT: dux functions related to text containing ANSI codes
 
@@ -21,11 +22,7 @@ Data::Unixish::ANSI - dux functions related to text containing ANSI codes
 
 =head1 VERSION
 
-version 0.05
-
-=head1 RELEASE DATE
-
-2014-04-24
+This document describes version 0.06 of Data::Unixish::ANSI (from Perl distribution Data-Unixish-ANSI), released on 2015-08-17.
 
 =head1 SYNOPSIS
 
@@ -61,11 +58,11 @@ feature.
 
 =head1 AUTHOR
 
-Steven Haryanto <stevenharyanto@gmail.com>
+perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Steven Haryanto.
+This software is copyright (c) 2015 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
